<?php

namespace Drupal\course_credit\Config\Entity;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Build a list of course credit types.
 */
class CourseCreditTypeListBuilder extends ConfigEntityListBuilder {

  public function buildRow(EntityInterface $entity) {
    $row['title'] = $entity->label() . ' (' . $entity->id . ')';
    $row['active'] = $entity->get('active') ? t('Yes') : t('No');
    $row['is_child_credit'] = $entity->get('sub') ? t('Yes') : t('No');
    $titles = [];
    foreach ($entity->get('sub_credits') ?? [] as $type) {
      $cct = \Drupal\course_credit\Entity\CourseCreditType::load($type);
      $titles[] = $cct->label();
    }

   $list = [
      '#theme' => 'item_list',
      '#items' => $titles,
    ];

    $row['assigned_child_credits'] = render($list);

    $row['weight'] = $entity->get('weight');
    $row += parent::buildRow($entity);
    return $row;
  }

  public function buildHeader() {
    $headers = [
      'Title',
      'Active',
      'Is child credit',
      'Assigned child credits',
      'Weight',
    ];

    $headers += parent::buildHeader();
    return $headers;
  }

  /**
   * {@inheritdoc}
   */
  function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    $operations['conditions'] = [
      'title' => $this->t('Conditions'),
      'url' => Url::fromRoute('entity.course_credit_type.conditions', ['course_credit_type' => $entity->id()]),
      'weight' => 50,
    ];
    return $operations;
  }

}
