<?php

namespace Drupal\course_credit\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;
use Drupal\rules\Engine\RulesComponent;
use Drupal\rules\Ui\RulesUiComponentProviderInterface;

/**
 * Defines the course type entity class.
 *
 * @ConfigEntityType(
 *   id = "course_credit_type",
 *   label = @Translation("Course credit type"),
 *   label_collection = @Translation("Course credit types"),
 *   label_singular = @Translation("course credit type"),
 *   label_plural = @Translation("course credit types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count course credit type",
 *     plural = "@count course credit types",
 *   ),
 *   admin_permission = "administer course credit type",
 *   config_prefix = "type",
 *   bundle_of = "course_credit",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "component",
 *     "active",
 *     "variable",
 *     "min",
 *     "max",
 *     "increments",
 *     "sub",
 *     "weight",
 *     "sub_credits"
 *   },
 *   handlers = {
 *     "access" = "Drupal\entity\EntityAccessControlHandler",
 *     "permission_provider" = "Drupal\entity\EntityPermissionProvider",
 *     "list_builder" = "Drupal\course_credit\Config\Entity\CourseCreditTypeListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *    "form" = {
 *       "default" = "Drupal\course_credit\Form\CourseCreditTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *   },
 *   links = {
 *     "add-form" = "/admin/course/credit-types/add",
 *     "edit-form" = "/admin/course/credit-types/manage/{course_credit_type}/edit",
 *     "delete-form" = "/admin/course/credit-types/manage/{course_credit_type}/delete",
 *     "collection" = "/admin/course/credit-types",
 *   }
 * )
 */
class CourseCreditType extends ConfigEntityBundleBase implements RulesUiComponentProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function getComponent() {
    if (empty($this->component)) {
      // Provide a default for now.
      // @todo make expression configurable.
      $this->component = [
        'expression' => ['id' => 'rules_and'],
        'context_definitions' => [
          'course_credit' => [
            'type' => 'entity:course_credit',
            'label' => 'Course credit instance',
            'description' => 'Course credit instance',
          ],
          'course_enrollment' => [
            'type' => 'entity:course_enrollment',
            'label' => 'Course enrollment',
            'description' => 'Course enrollment',
          ],
          'user' => [
            'type' => 'entity:user',
            'label' => 'User',
            'description' => 'User',
          ],
        ],
      ];
    }

    if (!isset($this->componentObject)) {
      $this->componentObject = RulesComponent::createFromConfiguration($this->component);
    }
    return $this->componentObject;
  }

  /**
   * {@inheritdoc}
   */
  public function updateFromComponent(RulesComponent $component) {
    $this->component = $component->getConfiguration();
    $this->componentObject = $component;

    return $this;
  }

}
