<?php

namespace Drupal\course_credit\Form;

use Drupal;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Html;
use Drupal\course_credit\Entity\CourseCreditType;

/**
 * Class CourseCreditSettingsForm.
 */
class CourseCreditSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'course_credit_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('course_credit.settings');
    $fallback_options[] = 'none';
    $result = CourseCreditType::loadMultiple();

    foreach ($result as $row) {
      $fallback_options[$row->id()] = strip_tags($row->label());
    }

    $form['skip_no_claim'] = array(
      '#type' => 'checkbox',
      '#title' => t('Automatically claim non-variable credit'),
      '#description' => t('When a user is only eligible for non-variable credit, credit will be claimed automatically.'),
      '#default_value' => $config->get('skip_no_claim'),
    );

    $form['allow_skip'] = array(
      '#type' => 'checkbox',
      '#title' => t('Allow skipping the credit claim form'),
      '#description' => t('A user does not have to claim any credit types.'),
      '#default_value' => $config->get('allow_skip'),
    );

    $form['select_all'] = array(
      '#title' => t('Credit claiming defaults'),
      '#type' => 'radios',
      '#options' => array(
        1 => t('Select all credit types'),
        0 => t('Do not select any credit types')
      ),
      '#description' => t('The user will have to opt out or in of credit type claiming depending on this configuration.'),
      '#default_value' => intval($config->get('select_all')),
    );

    $form['fallback_type'] = array(
      '#type' => 'select',
      '#title' => t('Fallback credit type'),
      '#description' => t('Credit to award when a user is not eligible for any others.'),
      '#options' => $fallback_options,
      '#default_value' => $config->get('fallback_type'),
    );

    $form['code'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable credit code settings on courses'),
      '#description' => t('This will enable credit code settings on all course edit forms.'),
      '#default_value' => $config->get('code'),
    );

    $form['variable'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable variable credit settings on courses'),
      '#description' => t('This will enable variable credit settings on all course edit forms.'),
      '#default_value' => $config->get('variable'),
    );

    $form['expiration'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable credit expiration settings on courses'),
      '#description' => t('This will enable credit type expiration settings on all course edit forms.'),
      '#default_value' => $config->get('expiration'),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->cleanValues();
    $this->config('course_credit.settings')
      ->setData($form_state->getValues())
      ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['course_credit.settings'];
  }

}
