<?php

namespace Drupal\course_credit\Form;

use Drupal\Core\Entity\BundleEntityFormBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Form\FormStateInterface;

class CourseCreditTypeForm extends BundleEntityFormBase {

  /**
   * @{inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $course_credit_type = $this->entity;

    $form['label'] = [
      '#title' => t('Label'),
      '#type' => 'textfield',
      '#default_value' => $course_credit_type->label(),
      '#description' => t('The admin-facing name.'),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $course_credit_type->id(),
      '#maxlength' => EntityTypeInterface::BUNDLE_MAX_LENGTH,
      '#machine_name' => [
        'exists' => '\Drupal\course_credit\Entity\CourseCreditType::load',
        'source' => ['label'],
      ],
    ];

    $form['description'] = [
      '#title' => t('Description'),
      '#type' => 'textarea',
      '#default_value' => $course_credit_type->description ?? '',
      '#description' => t('This text will be displayed on the <em>Add new content</em> page.'),
    ];

    $sub_types = array();
    foreach (course_credit_get_credit_types(1) as $type => $info) {
      if ($info->get('sub')) {
        $sub_types[$type] = $info->label();
      }
    }

    $form['#tree'] = TRUE;

    $form += array(
      'active' => array(
        '#title' => t('Active'),
        '#description' => t('Allow courses to use this credit type.'),
        '#type' => 'checkbox',
        '#default_value' => isset($course_credit_type->active) ? $course_credit_type->active : TRUE,
      ),
      'variable' => array(
        '#title' => t('Variable'),
        '#description' => t('The variable box will be checked by default on new courses.'),
        '#type' => 'checkbox',
        '#default_value' => isset($course_credit_type->variable) ? $course_credit_type->variable : FALSE,
      ),
      'min' => array(
        '#title' => t('Min'),
        '#type' => 'number',
        '#min' => '0',
        '#description' => t('The minimum amount that can be claimed.'),
        '#default_value' => isset($course_credit_type->min) ? $course_credit_type->min : 0.00,
        '#required' => TRUE,
      ),
      'max' => array(
        '#step' => 0.001,
        '#title' => t('Max'),
        '#type' => 'number',
        '#min' => '0',
        '#description' => t('The maximum amount that can be claimed. If non-variable, this value is used.'),
        '#default_value' => isset($course_credit_type->max) ? $course_credit_type->max : 0.00,
        '#required' => TRUE,
      ),
      'increments' => array(
        '#step' => 0.001,
        '#title' => t('Increments'),
        '#type' => 'number',
        '#min' => '0',
        '#description' => t('Credit claimed must be a multiple of this number.'),
        '#default_value' => isset($course_credit_type->increments) ? $course_credit_type->increments : 0.00,
        '#required' => TRUE,
      ),
      'sub' => array(
        '#step' => 0.001,
        '#title' => t('Is child credit?'),
        '#description' => t('Child credits can be applied to normal credit types.'),
        '#type' => 'checkbox',
        '#default_value' => isset($course_credit_type->sub) ? $course_credit_type->sub : FALSE,
      ),
      'weight' => array(
        '#title' => t('Weight'),
        '#type' => 'weight',
        '#description' => t('The weight of the credit type when being displayed in forms.'),
        '#default_value' => isset($course_credit_type->weight) ? $course_credit_type->weight : 0,
        '#size' => 5,
        '#required' => TRUE,
      ),
      'sub_credits' => array(
        '#title' => t('Allowed child credits'),
        '#description' => t('Child credit types can be applied to normal credit instances.'),
        '#type' => 'select',
        '#multiple' => TRUE,
        '#options' => $sub_types,
        '#default_value' => $course_credit_type->get('sub_credits') ?? [],
        '#states' => array(
          'invisible' => array(
            '#edit-sub' => array(
              'checked' => TRUE,
            ),
          ),
        ),
      ),
    );

    return $form;
  }

}
